LowerA <- function() {
    return(0)
}
UpperA <- function() {
    return(10)
}

LowerB <- function() {
    return(0)
}
UpperB <- function() {
    return(0.9999999)
}

LowerNu <- function() return(4.0)
UpperNu <- function() return(50)


